%%
%% This is the file `25onr_art.cls'
%% produced by J.W. Rottman based on 14 AFMC article class
%%
%%
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{25onr_art}[2004/04/06 25 ONR article class]

%% The 25onr template is a very narrow specification:
\DeclareOption{onecolumn}{\OptionNotUsed}
\DeclareOption{11pt}{\OptionNotUsed}
\DeclareOption{12pt}{\OptionNotUsed}
\DeclareOption{legalpaper}{\OptionNotUsed}
\DeclareOption{executivepaper}{\OptionNotUsed}
\DeclareOption{a4paper}{\OptionNotUsed}
\DeclareOption{a5paper}{\OptionNotUsed}
\DeclareOption{b5paper}{\OptionNotUsed}
\DeclareOption{titlepage}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions

\LoadClass[letterpaper,10pt,twocolumn,notitlepage,twoside]{article}
\usepackage{times}
%\usepackage{pslatex}
%%
%% Page Layout
%%
\renewcommand{\columnsep}{0.25in}
\setlength{\textheight}{9.0in}
\setlength{\textwidth}{6.5in}
\setlength{\oddsidemargin}{0.0in}
\setlength{\evensidemargin}{0.0in}
\setlength{\topmargin}{0.0in}
\setlength{\headsep}{0.0in}

%%
%% Font sizes
%% use of the cmr/cms bitmap fonts is discontinued because we
%% are using the times fonts -- for the sake of nice pdf
%%
\renewcommand{\normalsize}{\fontsize{10}{10}\selectfont}
\newcommand{\authorsize}{\fontsize{14}{14}\selectfont}
\newcommand{\titlesize}{\fontsize{18}{18}\selectfont}

%%
%% Sections etc
%% --- Just mimic what was in the original template, nothing fancy
%%     If we try to simply modify the definitions in article.cls,
%%     we find that we cannot reduce the space between the section
%%     title and the first line to zero ... hence the definitions
%%     below - which could be done equally well on a typewriter !
%%     Of course, without numbering, one cannot label and use \ref.
%%                                 }

\renewcommand{\section}{\@startsection {section}{1}{\z@}%
                                   {-3.5ex \@plus -1ex \@minus -.2ex}%
                                   {2.3ex \@plus.2ex}%
                                   {\normalsize\bfseries}}
                                   
\renewcommand{\subsection}{\@startsection{subsection}{2}{\z@}
                                   {12pt plus 4pt minus 2pt}
                                   {5pt plus 3pt}
                                   {\normalsize\sc\raggedright}}

\renewcommand{\subsubsection}{\@startsection{subsubsection}{3}{1em}
                                   {10pt plus 4pt minus 2pt}
                                   {3pt plus 3pt}
                                   {\normalsize\it\centering}}

\def\paragraph{\@startsection{paragraph}{4}{1em}
                                   {1pt}{-1em}
                                   {\normalsize\bf}}
\let\subsubsubsection\paragraph


%% Abstract:
%% use of unnumbered sections and two-column page layout
%% makes the abstract just another section
\renewenvironment{abstract}{\section{Abstract}}{}
\setcounter{secnumdepth}{0}

%%
%% Page headings 
%%  The first page contains the heading
%%    "25th Symposium on Naval Hydrodynamics
%%     St. John's, Newfoundland and Labrador, CANADA, 8-13 August 2004"
%%  So we define a new page style called onrhead and
%%  invoke it in the \maketitle.  The incantation is
%%  a modification of that found in Kopka & Daly, Appendix C.3.2
%%  The other pages contain no heading.

\pagestyle{plain}

\newcommand{\ps@onrhead}{%
  \renewcommand{\@oddhead}{\setlength{\unitlength}{1pt}%
    \renewcommand{\baselinestretch}{1.00}%
%    \begin{picture}(-0,0)(0,0)
    \begin{picture}(0,0)(0,0)
    \put(182,40){\parbox{4.0in}{\rmfamily \mdseries \raggedleft
            25$^{\rm{th}}$ Symposium on Naval Hydrodynamics \\
            St. John's, Newfoundland and Labrador, CANADA, 8-13 August 2004}}
    \end{picture}}
  \renewcommand{\@evenhead}{}
  \renewcommand{\@oddfoot}{}
  \renewcommand{\@evenfoot}{}
}


%\raggedbottom
%
% define paragraph format
\setlength{\parindent}{0.25in}
\setlength{\parskip}{1.0ex}
\setlength{\textfloatsep}{16pt plus 2pt minus 4pt}
%
%  expand the line spacing a bit. Is this enough ?
%  In future versions, it might be better use \fontsize for this?
\renewcommand{\baselinestretch}{1.15}
%


%
% set-up definitions for title (pinched from emac98.sty)
%
\def\affiliation#1{\gdef\@affiliation{#1}}
\gdef\@affiliation{}
\renewcommand{\maketitle}{\par
  \begingroup
    \renewcommand{\thefootnote}{\fnsymbol{footnote}}%
     \def\@makefnmark{\hbox to\z@{$\m@th^{\@thefnmark}$\hss}}%
    \long\def\@makefntext##1{\parindent 1em\noindent
            \hbox to1.8em{\hss$\m@th^{\@thefnmark}$}##1}%
    \if@twocolumn
      \ifnum \col@number=\@ne
        \@maketitle
      \else
        \twocolumn[\@maketitle]%
      \fi
    \else
      \newpage
      \global\@topnum\z@   % Prevents figures from going at top of page.
      \@maketitle
    \fi
    \thispagestyle{onrhead}\@thanks
  \endgroup
  \setcounter{footnote}{0}%
  \let\thanks\relax
\let\maketitle\relax \let\@maketitle\relax \gdef\@affiliation{}
 \gdef\@thanks{}\gdef\@author{}\gdef\@title{}\let\thanks\relax}
\def\@maketitle{%
  \newpage
 \null
 \begin{center}%
%  \vskip -2.5em%
   {\rmfamily \bfseries \titlesize \@title \par}%
   \vskip 1.0em%
   {\rmfamily \authorsize \@author \par}%
   \vskip 0.1em%
   {\rmfamily \authorsize \@affiliation \par}%
 \end{center}%
 \par
 \vskip 1.0em}
 
 %%to change how figures are labelled
\renewcommand\figurename{Figure}
\def\fnum@figure{\small \textrm{\textbf{\figurename~\thefigure:}}}
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{#1 #2}%
  \ifdim \wd\@tempboxa >\hsize
    #1 #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}
  
%%
%% references section
%%

\def\refname{\rmfamily \bfseries \normalsize References}

\renewcommand\@biblabel[1]{}
\renewcommand\newblock{\hskip .11em \@plus .33em \@minus .07em\relax}

\renewenvironment{thebibliography}[1]{%
  \par\vskip 20\p@ \@plus 1\p@ \@minus 1\p@
  \raggedright{\refname}%
  \nobreak
  \vskip 4\p@ \@plus .5\p@ \@minus .5\p@
  \nobreak
  \list{}{\labelwidth\z@ \leftmargin 2em \itemindent -2em \itemsep 1\p@}%
  \normalfont\small \parindent\z@
  \parskip\z@ \@plus .1\p@\relax
  \sloppy\clubpenalty4000\widowpenalty4000
  \sfcode`\.=1000\relax}
  {\endlist}

%% make citation <authorlastname (year)>
\renewcommand\@cite[2]{{#1\if@tempswa , #2\fi}}

%
% ignore requests for tableofcontents, listoffigures, listoftables.
% Discourage index.
%
\renewcommand{\tableofcontents}
             {\typeout{Request for tableofcontents is ignored.}}
\renewcommand{\listoffigures}
             {\typeout{Request for listoffigures is ignored.}}
\renewcommand{\listoftables}
             {\typeout{Request for listoftables is ignored.}}
\renewenvironment{theindex}
               {\typeout{Please do not put an index in your AFMC paper!}
                \if@twocolumn
                  \@restonecolfalse
                \else
                  \@restonecoltrue
                \fi
                \columnseprule \z@
                \columnsep 35\p@
                \twocolumn[\section{\indexname}]%
                \@mkboth{\MakeUppercase\indexname}%
                        {\MakeUppercase\indexname}%
                \thispagestyle{plain}\parindent\z@
                \parskip\z@ \@plus .3\p@\relax
                \let\item\@idxitem}
               {\if@restonecol\onecolumn\else\clearpage\fi}
